from distutils.core import setup

setup(
    name='clpszawesome',
    version='0.1.1',
    author='Peter Zuo',
    author_email='pengclpsz@gmail.com',
    packages=['clpszawesome'],
    url='https://github.com/clpsz',
    license='LICENSE.txt',
    description='first pypi',
    long_description='no long description',
    install_requires=[
    ],
)
